==> krb4-1.0pre2.tar.gz: krb4-1.0pre2/lib/krb/k_getsockinst.c <==
/*
 * Copyright (c) 1995, 1996, 1997 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "krb_locl.h"

RCSID("$Id: k_getsockinst.c,v 1.13 1999/12/02 16:58:42 joda Exp $");

/*
 * Return in inst the name of the local interface bound to socket
 * fd. On Failure return the 'wildcard' instance "*".
 */

int
k_getsockinst(int fd, char *inst, size_t inst_size)
{
  struct sockaddr_in addr;
  int len = sizeof(addr);
  struct hostent *hnam;

  if (getsockname(fd, (struct sockaddr *)&addr, &len) < 0)
    goto fail;

  hnam = gethostbyaddr((char *)&addr.sin_addr,
		       sizeof(addr.sin_addr),
		       addr.sin_family);
  if (hnam == 0)
    goto fail;

  strlcpy (inst, hnam->h_name, inst_size);
  k_ricercar(inst); /* Canonicalize name */
  return 0;			/* Success */

 fail:
  inst[0] = '*';
  inst[1] = 0;
  return -1;
}

==> krb4_1.2.2.orig.tar.gz: krb4-1.2.2/lib/krb/k_getsockinst.c <==
/*
 * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "krb_locl.h"

RCSID("$Id: k_getsockinst.c,v 1.14 2001/08/26 01:46:14 assar Exp $");

/*
 * Return in inst the name of the local interface bound to socket
 * fd. On Failure return the 'wildcard' instance "*".
 */

int
k_getsockinst(int fd, char *inst, size_t inst_size)
{
  struct sockaddr_in addr;
  socklen_t len = sizeof(addr);
  struct hostent *hnam;

  if (getsockname(fd, (struct sockaddr *)&addr, &len) < 0)
    goto fail;

  hnam = gethostbyaddr((char *)&addr.sin_addr,
		       sizeof(addr.sin_addr),
		       addr.sin_family);
  if (hnam == 0)
    goto fail;

  strlcpy (inst, hnam->h_name, inst_size);
  k_ricercar(inst); /* Canonicalize name */
  return 0;			/* Success */

 fail:
  inst[0] = '*';
  inst[1] = 0;
  return -1;
}
